@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2025 (C) Thomas Liske <thomas@fiasko-nw.net>
+#   2013 - 2022 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -52,26 +52,13 @@ my $LOGPREF = '[ucode]';
 sub compare_ucode_versions {
     my ($debug, $processor, %vars) = @_;
 
-    # if no firmware is available for the current CPU, that's
-    # considered up to date. the rationale here is that if we warn on
-    # this, we're actually going to warn for certain new CPUs that
-    # have an up-to-date, built-in firmware without any update. that,
-    # in turn, creates alert fatigue and makes operators more likely
-    # to ignore warnings.
-    unless ( exists( $vars{AVAIL} ) ) {
+    unless ( exists( $vars{CURRENT} ) && exists( $vars{AVAIL} ) ) {
+        print STDERR
+	    "$LOGPREF #$processor did not get current microcode version\n"
+	    if ( $debug && !exists( $vars{CURRENT} ) );
         print STDERR
 	    "$LOGPREF #$processor did not get available microcode version\n"
-	    if ( $debug );
-        return NRM_CURRENT;
-    }
-    # from here on, there is a microcode file available
-    #
-    # if we can't find a microcode firmware for the current CPU,
-    # *that* is a problem.
-    unless ( exists( $vars{CURRENT} )  ) {
-        print STDERR
-            "$LOGPREF #$processor did not get current microcode version\n"
-            if ( $debug);
+	    if ( $debug && !exists( $vars{AVAIL} ) );
 
         return NRM_UNKNOWN;
     }
@@ -154,15 +141,14 @@ sub nr_ucode_check {
         foreach my $pkg (@PKGS) {
             my @nvars;
             eval "\@nvars = ${pkg}::nr_ucode_check_real(\$debug, \$ui, \$processors{\$pid});";
-            if ( $@ ) {
-                print STDERR $@
-                    if ($debug);
+            if ( $@ && $debug ) {
+                print STDERR $@;
                 $ui->progress_step;
                 next;
             }
             $ui->progress_step;
 
-            my $nstate = compare_ucode_versions( $debug, $pid, @nvars );
+            my $nstate = compare_ucode_versions( $debug, $processors{processor}, @nvars );
             if ( $nstate > $state ) {
                 ( $state, @vars ) = ( $nstate, @nvars );
             }
